
# Slot: maximum_value


for slots with ranges of type number, the value must be equal to or lowe than this

URI: [linkml:maximum_value](https://w3id.org/linkml/maximum_value)


## Domain and Range

slot_definition &#8594;  <sub>0..1</sub> integer

## Parents


## Children


## Used by

 * anonymous_slot_expression
 * slot_definition
 * slot_expression
